#
# spec file for package linphone
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   9
%bcond_with linphone_gtkui
%bcond_without linphone_cplusplus
Name:           linphone
Version:        3.12.0
Release:        lp152.5.82
Summary:        Web Phone
License:        GPL-2.0+ AND GPL-3.0
Group:          Productivity/Networking/Other
Url:            https://linphone.org/technical-corner/liblinphone/overview
Source:         https://linphone.org/releases/sources/%{name}/%{name}-%{version}.tar.gz
Source1:        %{name}-manual.tar.bz2
Source2:        baselibs.conf
# PATCH-FIX-OPENSUSE linphone-fix-pkgconfig.patch sor.alexei@meowr.ru -- Install linphone.pc.
Patch0:         linphone-fix-pkgconfig.patch
# PATCH-FIX-OPENSUSE linphone-fix-gtkui-build.patch -- Fix building of GtkUI.
Patch1:         linphone-fix-gtkui-build.patch
# PATCH-FEATURE-OPENSUSE linphone-build-readline.patch sor.alexei@meowr.ru -- Add the ability to compile with readline to the build system.
Patch2:         linphone-build-readline.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libeXosip2-devel
BuildRequires:  libgsm-devel
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  sgmltool
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bctoolbox) >= 0.6.0
BuildRequires:  pkgconfig(belcard)
BuildRequires:  pkgconfig(belle-sip) >= 1.6.2
BuildRequires:  pkgconfig(libavcodec) >= 51.0.0
BuildRequires:  pkgconfig(libbzrtp) >= 1.0.6
BuildRequires:  pkgconfig(libosip2)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libswscale) >= 0.7.0
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(libv4l2) >= 0.8.4
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mediastreamer) >= 2.16.0
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(ortp) >= 1.0.2
BuildRequires:  pkgconfig(speex) >= 1.1.6
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(udev)
%if 0%{?suse_version} > 1320
BuildRequires:  python2
BuildRequires:  python2-six
BuildRequires:  python2-xml
%else
BuildRequires:  python
BuildRequires:  python-six
BuildRequires:  python-xml
%endif
%if %{with linphone_cplusplus}
%if 0%{?suse_version} > 1320
BuildRequires:  python2-pystache
%else
BuildRequires:  python-pystache
%endif
%endif
%if %{with linphone_gtkui}
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libnotify)
Requires:       lib%{name}-data = %{version}
Recommends:     %{name}-cli = %{version}
Obsoletes:      %{name}-lang < %{version}
%endif

%description
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package cli
Summary:        Web Phone Command Line Interface
Group:          Productivity/Networking/Other
Requires:       lib%{name}-data = %{version}

%description cli
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains the command line interface.

%package -n lib%{name}%{sover}
Summary:        Web Phone library
Group:          System/Libraries
Recommends:     lib%{name}-lang
Provides:       lib%{name} = %{version}

%description -n lib%{name}%{sover}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains a library.

%lang_package -n lib%{name}

%if %{with linphone_cplusplus}
%package -n lib%{name}++%{sover}
Summary:        Web Phone C++ library
Group:          System/Libraries

%description -n lib%{name}++%{sover}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains a C++ library.
%endif

%package -n lib%{name}-data
Summary:        Web Phone data files
Group:          Productivity/Networking/Other
BuildArch:      noarch

%description -n lib%{name}-data
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

This package contains data files such as sounds.

%package -n lib%{name}-devel
Summary:        Web Phone Development files
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       lib%{name}%{sover} = %{version}
Requires:       lib%{name}-data = %{version}
Requires:       libeXosip2-devel
Requires:       libosip2-devel
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(libavcodec) >= 51.0.0
Requires:       pkgconfig(libswscale) >= 0.7.0
Requires:       pkgconfig(speex)
# linphone-devel was last used in openSUSE Leap 42.3.
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
%if %{with linphone_cplusplus}
Requires:       lib%{name}++%{sover} = %{version}
%endif

%description -n lib%{name}-devel
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%prep
%setup -q
%setup -q -D -T -a 1
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%cmake \
  -DPYTHON_EXECUTABLE="%{_bindir}/python2" \
%if %{with linphone_cplusplus}
  -DENABLE_CXX_WRAPPER=ON      \
%else
  -DENABLE_CXX_WRAPPER=OFF     \
%endif
  -DENABLE_ROOTCA_DOWNLOAD=OFF \
  -DENABLE_ZRTP=ON             \
  -DENABLE_LDAP=ON             \
%if %{with linphone_gtkui}
  -DENABLE_GTK_UI=ON           \
%endif
  -DENABLE_TOOLS=OFF           \
  -DENABLE_STRICT=OFF          \
  -DENABLE_STATIC=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}/%{name}/
mv -T %{buildroot}%{_datadir}/doc/%{name}-%{version}/ \
  %{buildroot}%{_docdir}/%{name}/

%if %{with linphone_gtkui}
install -Dpm 0755 share/%{name}.appdata.xml \
  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%suse_update_desktop_file -r -D "%{name}/index.xml.html" %{name} Network Telephony
# Remove a duplicate COPYING.
rm -f %{buildroot}%{_datadir}/%{name}/COPYING
%endif

# Install the manual.
mkdir -p %{buildroot}%{_datadir}/gnome/help/
cp -a %{name} %{buildroot}%{_datadir}/gnome/help/%{name}/
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} <= 1320 && %{with linphone_gtkui}
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%post -n lib%{name}%{sover} -p /sbin/ldconfig

%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%if %{with linphone_cplusplus}
%post -n lib%{name}++%{sover} -p /sbin/ldconfig

%postun -n lib%{name}++%{sover} -p /sbin/ldconfig
%endif

%if %{with linphone_gtkui}
%files
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/audio-assistant.desktop
%{_datadir}/icons/hicolor/*/*/%{name}*
%{_datadir}/pixmaps/%{name}/
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%endif

%files cli
%{_bindir}/%{name}c*
%{_bindir}/%{name}-daemon*

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.%{sover}*

%files -n lib%{name}-lang -f %{name}.lang
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/

%if %{with linphone_cplusplus}
%files -n lib%{name}++%{sover}
%{_libdir}/lib%{name}++.so.%{sover}*
%endif

%files -n lib%{name}-data
%doc AUTHORS COPYING NEWS README.md
%doc %{_docdir}/%{name}/
%{_datadir}/sounds/%{name}/

%files -n lib%{name}-devel
%{_includedir}/%{name}*/
%{_bindir}/lib%{name}_tester
%{_libdir}/lib%{name}.so
%if %{with linphone_cplusplus}
%{_libdir}/lib%{name}++.so
%endif
%{_datadir}/liblinphone_tester/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/Linphone/
%if %{with linphone_cplusplus}
%{_datadir}/LinphoneCxx/
%endif

%changelog
* Wed Feb 21 2018 sor.alexei@meowr.ru
- Add linphone-build-readline.patch: Add the ability to compile
  with readline to the build system.
- Build with the readline support.
* Mon Feb 19 2018 sor.alexei@meowr.ru
- Revert back to Python2: building with Python3 has regressions
  (boo#1077857).
* Fri Jan 19 2018 sor.alexei@meowr.ru
- Switch to building with Python3.
* Thu Nov  9 2017 olaf@aepfle.de
- Use linphone_gtkui conditionally everywhere
* Mon Oct 30 2017 olaf@aepfle.de
- Use build conditional for C++ bindings also in liblinphone-devel
* Wed Oct  4 2017 olaf@aepfle.de
- Add build condtionally for C++ bindings to fix build in Leap
- Remove build conditionally for ffmpeg
- Remove build conditionally for ldap
- Remove unused BuildRequires for disabled rootca download
* Fri Sep 22 2017 sor.alexei@meowr.ru
- Provide liblinphone for the liblinphone-lang package.
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Fix the licence: there are GPL-3.0 licensed files.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 3.12.0:
  * C++ and C# bindings.
  * Account Creator plugin API.
  * Xamarin support.
- Switch from building with autotools to cmake.
- Add linphone-fix-pkgconfig.patch: Install linphone.pc.
- Add linphone-fix-gtkui-build.patch: Fix building of GtkUI.
- Disable the deprecated GTK+ UI for openSUSE Leap 15.x and newer,
  but keep for older as the Qt inteface requires Qt 5.9+.
- Split libraries, data files and the CLI.
- Enable building C++ bindings.
- Add baselibs.conf.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 3.11.1 (changes since 3.10.2):
  * Security vulnerability fix concering TLS. The common name of
    certificats delivered by SIP proxies were not compared with
    their host name.
  * Fix a bug in the P2P presence system. Unchecking
    "Allow this contact to see my presence" check box in contact
    editing view had no any effect. Then it was not possible to
    hide presence informations to a contact once it had been
    allowed to see it.
  * Performance improvments of the presence list feature.
  * IM Encription Engine: Abstraction for messaging encription
    protocols.
  * A bug fix in Autotools scripts.
* Wed Feb 22 2017 fcrozat@suse.com
- Ensure %%icon_theme_cache_* macros are called in post/postun
  scripts.
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Update to version 3.10.2 (changes since 3.9.1):
  * Add lime_experimental_feature: set to 1 in .linphonerc [GtkUi]
    to show the Lime menu in the graphical user interface.
    Caution: Experimental.
  * Video conference support through a conference server (SDK only).
  * Disable dummy STUN packets sending when ICE is activated.
  * Signal AVPF support as AVP: Enable rtcp feedback on RTP/AVP by
    default.
  * Add linphone daemon.
  * gtk: Show links to files received in chat by file transfer.
  * gtk: Debug window now stores "scroll to end" preference.
  * gtk: Add button to take screenshot of video call.
  * gtk: Fix busy presence not displayed in red.
  * Fix Bad SDP when no audio codec has been enabled.
  * Fix DTMF RFC2833 event always goes up in the same
    LinphoneCoreListener.
  * Fix linphone python version compilation - fixing vcards.
* Mon Aug  8 2016 olaf@aepfle.de
- Use ffmpeg buildconditional also in devel pkg
* Thu Aug  4 2016 olaf@aepfle.de
- Build with ffmpeg unconditionally
- Remove unused gl,glew,vpx,xv
* Tue Jun 28 2016 bwiedemann@suse.com
- require a recent enough libbellesip0 package to run (bnc#957599)
* Thu Nov 19 2015 mpluskal@suse.com
- Update to 3.9.1
  * Fix crash when recording video calls with the VP8 codec
  * Fix H.264 codec support in Mac OS X package
  * Fix translation of account assistant
  * Bug fixes
- Make build more verbose
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 3.9.0:
  * Video recording of calls in MKV format.
  * Clickable URLs in chat view.
  * Add buttons to change the record and playback volumes during a
    call.
  * Add button to start chatting without having to create a contact
    first.
  * Some icon changes.
  * Call logs now stored in database.
  * Bug fixes.
* Mon Sep 21 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg to fix build in PMBS
* Tue Sep  8 2015 sor.alexei@meowr.ru
- Update to 3.8.5 (changes since 3.8.0):
  + Application level improvements:
  * Auto-answer ability.
  * Add support of the StatusNotifierItem standard (modern
    GNU/Linux status icons).
  * Auto-answering can be set through the preferences panel.
  * Fix crash at the end of the audio assistant.
  * Fix crash when configuring a remote provisioning.
  * Fix regretion in the codec view. Codec which are not usable
    because bandwitch limits are to low were not grayed anymore.
  * Bug fixes.
  * Add translation for 'Arabic' and 'Turkish' items in the
    language selection list
  + Liblinphone level improvements:
  * Fix audio bug with OPUS codec.
  * Fix ICE corner case not properly handled and resulting bad
    final ice status.
  * Update shared library ABI version to 7 (it should had been
    done in 3.8.0).
  * Bug fixes.
  * Add a built-in XMLRPC client. Linphone does not depend on
    libsoup anymore.
- Build with video support outside PMBS for openSUSE Leap 42.1
  and newer (where ffmpeg is available).
* Sun Apr  5 2015 fisiu@opensuse.org
- Enable ldap support.
* Sat Mar 28 2015 sor.alexei@meowr.ru
- Regenerate configure with autotools to solve build problems in
  some cases.
- Remove redefinition of GenericName in desktopfile.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 3.8.0:
  + Application level improvements:
  * The video window has now controls in order to switch
    fullscreen mode and terminate call.
  * The out of call video preview feature (to test camera) is
    moved into the settings and is no longer linked to the in-call
    video preview feature.
  * Add an assistant to help users to set audio/video parameters.
  * Some ergonomics improvments (checkbox to set random port for
    UDP and TCP, ...).
  * Lots of updated translations. Arabic translation has been
    added.
  * Experimental feature: play an MKV file by drag-and-dropping
    it on the video call window.
  + Liblinphone level improvements:
  * Support for RTP/AVPF (RFC4585) for video streams, allowing fast
    transmission error recovery with VP8 codec only.
  * API enhancements, most objects can be ref-counted.
  * Add some getter funtctions to the call information API.
  * Add a function in the API to accept early-media calls.
  * Add a function to set the SIP transport timeout.
  * Add a function to change adaptive rate algorithm at runtime.
  * Add support of file transfer.
  * Call video recording feature, in mkv format (H264 streams only
    for the moment).
  * Call playing feature: play an MKV file and send the audio/video
    stream through a call.
  * Local player API. Play WAV and MKV file and display video on a
    specified window display.
  * A wrapper for Python has been made.
  * Support of multicast IP addresses.
  * Support of incoming UPDATEs within dialog (RFC3311).
  * Support of SRTP by using packages from distributions.
- Spec cleanup.
* Fri Aug 15 2014 fisiu@opensuse.org
- Update to 3.7.0:
  Application level improvements:
  * It is now possible to configure multiple proxy accounts with different
    transports (UDP, TCP, TLS)
  * can work with IPv6 and IPv4 simultaneously
  * User can choose video rendering method on Linux
  * Video HD formats support added, leveraging on multiple cores for encoding
    if available
  * Keyboard can be used for DTMF input
  * Faster and higly responsive UI thanks to fully asynchronous operation of
    the liblinphone.
  * Addon of opus codec
  * Possibility to specify a remote provisionning http URI for configuration
  * LDAP search integration for Linux and MacOSX
  * is-composing notification in chat area
  Liblinphone level improvements thanks to new "belle-sip" SIP stack:
  * multiple SIP transports simultaneously now allowed
  * IP dual stack: can use IPv6 and IPv4 simultaneously
  * fully asynchronous behavior: no more lengthly DNS or connections
  * +sip.instance parameter (RFC5626)
  * alias parameter (RFC5923)
  * better management of network disconnections
  * SIP/TLS handled through lightweighted polarssl library (instead of
    openssl)
  * SIP transaction state machines improved (RFC6026)
  * Privacy API (RFC3323, RFC3325)
  * Full support of rich presence in (RFC4480)
  * Better handling of sips scheme in URIs.
  * Messaging: support of is-composing (RFC3994)
  * Call transfer fixes in error cases
  * Add API for managing SIP SUBSCRIBES/NOTIFY/PUBLISH (linphonecore/event.h)
  * bugfixes
* Tue Feb 11 2014 zaitor@opensuse.org
- Version pkgconfig(libzrtpcpp) BuildRequires to resolve build for
  13.2 and newer.
* Thu Jun 20 2013 fisiu@opensuse.org
- Update to 3.6.1:
  * UI:
  * new friend list and chat messaging UI
  * enhanced call history
  * call and conference audio recording
  * persistent chat history
  * DSCP settings for SIP and RTP
  * display of call statistics (when clicking on the quality indicator bar)
  * Core:
  * ICE for efficient RTP exchange
  * fix bug in zRTP support (upgrade required)
  * call recording
  * uPnP
  * call statistics
  * adaptive bitrate control improvements
  * faster call quality indicator feedback
  * DSCP settings for SIP and RTP
  * detailed call statistics feedback API
- Drop linphone-ffmpeg.patch and linphone-v4l.patch: they were for
  shipped mediastreamer but we're using external one.
- Spec cleanup.
* Sat Mar  2 2013 seife+obs@b1-systems.com
- fix build with automake-1.13.1
* Mon Nov 12 2012 mailaender@opensuse.org
- add libsrtp and libzrtpcpp as build dependency
* Sat Oct 27 2012 mailaender@opensuse.org
- use external libortp and mediastreamer2
* Fri Oct 12 2012 vadimuzzz@inbox.ru
- added video support (disabled by default), to enable need to rebuild "with video"
- modify patch linphone-v4l (ffmpeg API changed)
- added linphone-ffmpeg.patch (ffmpeg API changed)
* Mon May 21 2012 jengelh@inai.de
- Use BuildRequires: pkgconfig(gnutls) instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Tue May 15 2012 i@marguerite.su
- update to version 3.5.2
  * updated oRTP to 0.20.0
  * updated mediastreamer2 to 2.8.2
  * added ZRTP media encryption
  * added SILK audio codec
- modify patch linphone-v4l.
- drop applet sub-package. since no useful data.
* Thu Nov 24 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 24 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jul 24 2011 seife+obs@b1-systems.com
- update to version 3.4.3, see NEWS file for detailed changelog,
  obsoletes patches
- build / packaging improvements:
  - remove build date from binaries, use the tarball's timestamp
  - verbose build for rpmlint checking
  - add AUTHORS, NEWS, COPYING files
  - fix rpm group of devel package
  - add alsa-devel and libgsm-devel buildrequires
  - explicitly enable alsa, ssl, rsvp, ipv6
* Tue Jul 12 2011 cwh@novell.com
- fixing 11.4 build
* Thu Jul  7 2011 idonmez@novell.com
- Add linphone-v4l-2.6.38.patch: use new v4l interface
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Jan 16 2011 seife+obs@b1-systems.com
- Patch up to current git state of branch 3.3.x. Unfortunately,
  the git history is not helpful to create a changelog.
  But this fixes bnc#664808.
* Wed Dec 29 2010 aj@suse.de
- Run spec file through spec-cleaner.
- Remove build dependencies on libgnomeprintui-devel and
  libwnck-devel, they are not needed.
* Thu Nov 11 2010 coolo@novell.com
- own parent directory for gnome-panel
* Wed Aug 11 2010 ro@suse.de
- update to linphone-3.3.2
  * enhancements made to presence support (SIP/SIMPLE)
  * be nat friendly using OPTIONS request and using received,rport from
  responses.
  * use stun guessed ports even if symmetric is detected (works with freeboxes)
  * improve bitrate usage of speex codec
  * allow speex to run with vbr (variable bit rate) mode
  * add speex/32000 (ultra wide band speex codec)
  * answer empty SIP INFO requests
  * reverse order of call logs
  * optimize video display
  * manual or automatic network connectivity management (so that REGISTERs
  are only sent when network is up or refreshed when it comes back)
  * new in-call layout
  * new idle view with two buttons
  * ability to dial the number from dialpad
  * improve local IP address detection when having multiple networks (ex: VPNs)
  * use proxy's received and rport params from via in Contact header when possible
  * add an option to ask linphone to place a call, whenever an instance is already running or not:
  should be useful for starting calls from a web browser recognizing the 'sip:' uri scheme.
  * don't show ffmpeg codecs when encoder are disabled in ffmpeg library.
  * update theora default settings to match performance of 1.0 release.
  * linphone can now send large video pictures: up to SVGA, configurable via the user interface
  * automatic rescaling of the video windows to the video size of incoming stream
  * enable lookups of SRV records
  * new 'linphonecsh' program to send commands to a linphonec running as daemon using unix sockets or tcp.
  - tons of bugfixes, please see NEWS file for details
- update to version 3.0.0
  * new graphical interface based on Glade/Gtk
  * systray icon
  * STUN working for RTP
  * accurate bandwidth management (to let video occupy all remaning bandwidth)
  * new H264 plugin based on x264 (msx264)
  * automatic call hangup upon media transmission faillure
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Mon May 25 2009 hvogel@suse.de
- Translations update
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Wed Oct 22 2008 hvogel@suse.de
- get rid of autoreconf call to make it build again
* Fri Apr 18 2008 hvogel@suse.de
- Hide online help button, we dont have an XML file to pass to
  gnome_help_display so its of no use.
* Thu Apr  3 2008 hvogel@suse.de
- update to version 2.1.1
  * Clean up commands 'nat', 'stun' and 'firewall' to be
    more intuitive
  * Upgrade to newest gettext
- fix some rpmlint warnings
- get rid of libtool archives
* Fri Jan 18 2008 mskibbe@suse.de
- portate to new libosip version
- fix typo in linphone-1.3.0.patch
* Wed Jan 16 2008 mskibbe@suse.de
- update to version 2.0.1 which
  o use new (eX)osip version
  o Clean ANSI/C vs. ANSI/C++ differences
  o fix a lot of small bugs
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Sep  4 2007 mskibbe@suse.de
- update to versin 1.7.1:
  * arts sound input/output
  * improved sound latency with alsa
  * alsa support works with dmix/dsnoop
  * fix a lot of bugs
* Tue Jun 19 2007 mskibbe@suse.de
- disable Werror
* Wed May 16 2007 ro@suse.de
- use libosip2-devel in buildrequires
* Thu Mar  8 2007 mskibbe@suse.de
- add missing directories
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Feb  8 2007 mskibbe@suse.de
- fix build problems
* Tue Jan 16 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Aug 10 2006 mskibbe@suse.de
- update to version 1.3.0 which includes
  o a lots of improvements in linphonec (see strk 's Changelogs below)
  o telephone event problem with sipomatic.
  o updated cz translation.
  o fix bugs around addressbook.
  o video support with H263-1998/RFC2429 nearly clean.
  o added timeout for incoming calls
* Sat Feb 18 2006 gekker@suse.de
- Update .desktop file for UI team
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hvogel@suse.de
- Update to version 1.2.0
* Fri Nov 11 2005 hvogel@suse.de
- care about return values. Added
  * linphone-returnchecks.patch
* Wed Oct  5 2005 hvogel@suse.de
- update to version 1.1.0 drop
  * linphone-manual.patch
  * linphone-cs_cz.patch
  * linphone-cs_cz-fixes.patch
  * linphone-configure.patch
* Fri Sep  9 2005 hvogel@suse.de
- update cz translation
* Fri Jul  8 2005 mmj@suse.de
- fix more prototypes
* Tue Jul  5 2005 mmj@suse.de
- fix unitialized vars
- fix prototypes
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Wed Apr 20 2005 hvogel@suse.de
- fix bonobo server file to include an icon
- fix desktop file to have both Name and GenericName
- fix return values
* Tue Mar 22 2005 max@suse.de
- Update to final 1.0.0 version, which is more stable (#74253).
* Tue Mar 22 2005 sbrabec@suse.cz
- Moved applet bonobo server description to linphone-applet.
* Tue Mar 22 2005 coolo@suse.de
- split the gnome applet into an own package (#74199)
* Thu Mar 17 2005 hvogel@suse.de
- fix desktop file
* Tue Feb 15 2005 ro@suse.de
- added czech translations by Klara Cihlarova
* Thu Feb  3 2005 hvogel@suse.de
- add the manual so the manual button works
* Mon Jan 24 2005 ro@suse.de
- mark as NoSource (ffmpeg is there but unused).
* Wed Jan 19 2005 ro@suse.de
- update to 1.0.0pre6
- fixed more compiler warnings
* Sun Nov 14 2004 ro@suse.de
- fix another compile warning
* Tue Nov  9 2004 ro@suse.de
- update to 1.0.0pre4
- split patch in pieces
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed applet broken by bad libdir usage.
- Fixed libexecdir for bi-arch (#47050).
* Wed Jul 28 2004 ro@suse.de
- update to 1.0.0pre1
* Wed May 19 2004 ro@suse.de
- update to 0.12.2
- fix some compiler warnings
* Tue Feb  3 2004 ro@suse.de
- use -fno-strict-aliasing
* Wed Jan 21 2004 ro@suse.de
- update to 0.12.1
- make it build
* Mon Oct 20 2003 ro@suse.de
- don't build as root
* Sat Aug 23 2003 ro@suse.de
- update to 0.12.0
* Tue Jul 29 2003 ro@suse.de
- install it all to /opt/gnome
* Thu Jul 17 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
- Added gnome-panel to neededforbuild.
* Wed Jun 11 2003 ro@suse.de
- fix desktop file path
* Wed Jun 11 2003 ro@suse.de
- libtoolize in osipua subdirectory for proper soname
* Tue Jun 10 2003 ro@suse.de
- created package (version 0.11.0)
- use system speex library
